@@ -478,7 +478,7 @@ class SessionCollector(SH):
 
     def get_server_id(self, name):
         # code is a unique value
-        u = self.session.query(ServerInstance).filter_by(ServerInstance.host_name.ilike(name)).all()
+        u = self.session.query(ServerInstance).filter(ServerInstance.host_name.ilike(name)).all()
         if u:
             return u[0]
         else:
